﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2008 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.Hive.Contracts.Interfaces;
using HeuristicLab.Hive.Contracts;
using HeuristicLab.Hive.Contracts.BusinessObjects;
using HeuristicLab.Hive.Server.DataAccess;

namespace HeuristicLab.Hive.Server.Core {
  public class ExecutionEngineFacade : IExecutionEngineFacade {

    private IJobManager jobManager = ServiceLocator.GetJobManager();
    private IContextFactory contextFactory = ServiceLocator.GetContextFactory();

    public ExecutionEngineFacade() {
    }

    #region IExecutionEngineFacade Members

    public ResponseObject<JobDto> AddJob(SerializedJob job) {
      using (contextFactory.GetContext()) {
        return jobManager.AddNewJob(job);
      }
    }

    public ResponseObject<JobDto> AddJobWithGroupStrings(SerializedJob job, IEnumerable<string> resources) {
      using (contextFactory.GetContext()) {
        return jobManager.AddJobWithGroupStrings(job, resources);
      }
    }

    public Response RequestSnapshot(Guid jobId) {
      using (contextFactory.GetContext()) {
        return jobManager.RequestSnapshot(jobId);
      }
    }

    public ResponseObject<SerializedJob> GetLastSerializedResult(Guid jobId, bool requested, bool snapshot) {
      using (contextFactory.GetContext(false)) {
        return jobManager.GetLastSerializedJobResultOf(jobId, requested, snapshot);
      }
    }

    public ResponseObject<JobDto> GetJobById(Guid jobId) {
      using (contextFactory.GetContext(false)) {
        return jobManager.GetJobById(jobId);
      }
    }

    public Response AbortJob(Guid jobId) {
      using (contextFactory.GetContext()) {
        return jobManager.AbortJob(jobId);
      }
    }
    #endregion
  }
}
